var fs = require("fs");
var path = require("path");
var Parser = require("i18next-scanner").Parser;
const zhExclude = require("./i18n_exclude_zh.json");
const enExclude = require("./i18n_exclude_en.json");
const existedEn = require("../src/i18n/en.json");

var directoryPaths = ["src/pages", "src/components"];
var existedEnTranslation = existedEn.translation;

var zhHandler = function (key) {
  /// 读取特殊规则，如果有特殊规则，就从特殊规则取值
  if (zhExclude[key]) {
    zhParser.set(key, zhExclude[key]);
    return;
  }
  zhParser.set(key, key);
};

var enHandler = function (key) {
  /// 读取特殊规则，如果有特殊规则，就从特殊规则取值
  if (enExclude[key]) {
    enParser.set(key, enExclude[key]);
    return;
  }
  /// 如果已经有翻译，就从已有翻译取值
  if (existedEnTranslation[key]) {
    enParser.set(key, existedEnTranslation[key]);
    return;
  }
  var defaultValue = "__TRANSLATION__";
  enParser.set(key, defaultValue);
};

var zhParser = new Parser();
var enParser = new Parser();

function processDirectory(directoryPath) {
  const files = fs.readdirSync(directoryPath);

  for (let file of files) {
    let fullPath = path.join(directoryPath, file);

    if (fs.statSync(fullPath).isDirectory()) {
      processDirectory(fullPath);
    } else {
      let content = fs.readFileSync(fullPath, "utf-8");

      zhParser.parseFuncFromString(content, { list: ["t"] }, zhHandler);
      enParser.parseFuncFromString(content, { list: ["t"] }, enHandler);
    }
  }
}

// Process all directories
for (let directoryPath of directoryPaths) {
  processDirectory(directoryPath);
}

var zhTranslations = zhParser.get({ sort: true });
var enTranslations = enParser.get({ sort: true });

// 写入翻译到目标json文件
fs.writeFileSync(
  "src/i18n/zh.json",
  JSON.stringify(zhTranslations.en, null, 2)
);

fs.writeFileSync(
  "src/i18n/en.json",
  JSON.stringify(enTranslations.en, null, 2)
);

var fileTranslations = Object.keys(zhTranslations.en.translation).length;
console.log("✅ 翻译查找完成，共找到 " + fileTranslations + " 个翻译项");
