import React, { useEffect, useState } from 'react';
import PropTypes from 'prop-types';
import Spacer from '../public/Spacer';
// import * as Tabs from '@radix-ui/react-tabs';
import classNames from 'classnames';

// assets
import download_bg from '../../assets/imgs/download_bg.png';
import download_qrcode from '../../assets/imgs/qr_codes/download_qrcode.png';
import download_qrcode_en from '../../assets/imgs/qr_codes/download_qrcode_en.png';
import SVGIcon from '../svg/SVGIcon';

const SectionDownload = ({ t, isCN }) => {
  // const DOWNLOADS_TABS = ['stable', 'preview'];

  const [config, setConfig] = useState({});
  // const [activeTab, setActiveTab] = useState(DOWNLOADS_TABS[0]);

  const getConfig = (isCN) => {
    /// 获取当前时间戳作为版本号
    const timestamp = new Date().getTime();
    const configUrl = isCN
      ? '/app_params_zh.json?v=' + timestamp
      : '/app_params_en.json?v=' + timestamp;
    fetch(process.env.PUBLIC_URL + configUrl, {
      headers: {
        'Content-Type': 'application/json',
        Accept: 'application/json',
      },
    })
      .then(function (response) {
        return response.json();
      })
      .then(function (config) {
        setConfig(config);
      });
  };

  // const _handleTabChange = (value) => {
  //   setActiveTab(value);
  // };

  useEffect(() => {
    getConfig(isCN);
  }, [isCN]);

  // 处理打开新窗口
  const _handleWindowOpen = (url) => {
    window.open(url);
  };

  // const _buildStaDownloadButton = ({ platformType, buttonString, onClick }) => {
  //   return (
  //     <div
  //       onClick={onClick}
  //       className='group hover:bg-gray-100 duration-300 cursor-pointer w-full h-[8vh] p-[2vh] flex flex-row items-center justify-center rounded border'>
  //       <SVGIcon type={platformType} />
  //       <div className='ml-3 bg-gradient-text text-transparent bg-clip-text group-hover:text-blue-500 duration-300 tracking-widest-cn'>
  //         {buttonString}
  //       </div>
  //     </div>
  //   );
  // };

  const _buildPreDownloadButton = ({ platformType, buttonString, onClick }) => {
    return (
      <div
        onClick={onClick}
        className='group hover:bg-gray-100 duration-300 cursor-pointer w-full h-[8vh] p-[2vh] flex flex-row items-center justify-center rounded border'>
        <SVGIcon type={platformType} />
        <div className='ml-3 font-thin text-white  group-hover:text-blue-500 duration-300 tracking-widest-cn'>
          {buttonString}
        </div>
      </div>
    );
  };

  // const _buildTextButton = ({ buttonString, onClick }) => {
  //   return (
  //     <div
  //       onClick={onClick}
  //       className='group hover:bg-gray-100 duration-300 cursor-pointer w-full h-[8vh] p-[2vh] flex flex-row items-center justify-center rounded border'>
  //       <div className='bg-gradient-text text-transparent bg-clip-text group-hover:text-blue-500 duration-300 tracking-widest-cn'>
  //         {buttonString}
  //       </div>
  //     </div>
  //   );
  // };

  const _buildLoginButton = ({ onClick }) => {
    return (
      <div
        onClick={onClick}
        className='group hover:bg-gray-100 duration-300 cursor-pointer w-full h-[8vh] p-[2vh] flex flex-row items-center justify-center rounded border'>
        <SVGIcon type={'web-pre'} />
        <div className='ml-3 font-thin text-white group-hover:text-blue-500 duration-300 tracking-widest-cn'>
          {t('直接登录 Web 版')}
        </div>
      </div>
    );
  };

  const _buildTabContainerClass = classNames(
    'grid grid-cols-2 w-[200%] duration-500',
    // {
    //   // hidden: activeTab !== tab,
    //   '-translate-x-[50%]': activeTab !== DOWNLOADS_TABS[0],
    //   'translate-x-0': activeTab === DOWNLOADS_TABS[0],
    // },
  );

  return (
    <>
      {/* 背景图 */}
      <div className='absolute bg-slate-100 h-full'>
        <img
          src={download_bg}
          alt='download_bg'
          className='animate-displayFromTransparent z-0 w-full min-h-full object-cover'
        />
      </div>
      <div className='pt-8 flex flex-col w-full h-full items-center justify-evenly z-10'>
        <div className='font-bold text-white text-4xl lg:text-6xl duration-300 tracking-widest-cn'>
          {t('软件下载')}
        </div>
        <div className='hidden md:flex  flex-col items-center'>
          <img
            src={isCN ? download_qrcode : download_qrcode_en}
            alt='download_qrcode'
            className='w-[120px] h-[120px] object-cover hover:w-[250px] hover:h-[250px] duration-300 cursor-pointer rounded'
          />
          <Spacer height={'20px'} />
          <div className='font-thin text-white text-xl duration-300 tracking-widest-cn'>
            {t('扫描二维码下载手机客户端')}
          </div>
        </div>
        <div className='flex flex-col px-3 w-full md:w-1/2 shadow-[0_2px_10px] shadow-blackA4'>
          <div className='grow md:backdrop-blur-sm md:bg-white md:bg-opacity-20 rounded-md outline-none overflow-x-hidden'>
            <div className={_buildTabContainerClass}>
              <div className='grid grid-cols-1 md:grid-cols-2 gap-6 p-5'>
                <_buildPreDownloadButton
                  platformType='android-pre'
                  buttonString={t('Android 客户端下载')}
                  onClick={() =>
                    _handleWindowOpen(config.FLYINSONO_ANDROID_DOWNLOAD_URL)
                  }
                />
                <_buildPreDownloadButton
                  platformType='apple-pre'
                  buttonString={t('iOS 客户端下载')}
                  onClick={() =>
                    _handleWindowOpen(config.FLYINSONO_IOS_DOWNLOAD_URL)
                  }
                />
                <div className='hidden md:block'>
                  <_buildPreDownloadButton
                    platformType='windows-pre'
                    buttonString={t('Windows 客户端下载')}
                    onClick={() =>
                      _handleWindowOpen(config.FLYINSONO_WINDOWS_DOWNLOAD_URL)
                    }
                  />
                </div>
                <div className='hidden md:block'>
                  <_buildLoginButton
                    onClick={() =>
                      _handleWindowOpen(config.FLYINSONO_WEB_APP_URL)
                    }
                  />
                </div>
              </div>
              <div className='flex flex-col items-center justify-center'>
                <div className='m-4 text-xl text-white tracking-widest-cn'>
                  {t('请联系杏聆荟团队获取')}
                </div>
                <div className='text-xl text-white'></div>
                <a
                  href='mailto:xinglinghui@vinno.com'
                  className='m-4 font-thin text-xl text-white hover:underline underline-offset-4  mt-1 duration-300 cursor-pointer'
                  target='_blank'
                  rel='noreferrer'>
                  {'xinglinghui@vinno.com'}
                </a>
              </div>
            </div>
          </div>
        </div>
      </div>
    </>
  );
};

SectionDownload.propTypes = {
  t: PropTypes.func.isRequired,
  isCN: PropTypes.bool.isRequired,
};

export default SectionDownload;
