import React from 'react';
import PropTypes from 'prop-types';
import { scroller } from 'react-scroll';

import features_bg from '../../assets/imgs/features_bg.png';
import features_A from '../../assets/imgs/feature_icons/features_A.png';
import features_B from '../../assets/imgs/feature_icons/features_B.png';
import features_C from '../../assets/imgs/feature_icons/features_C.png';
import features_D from '../../assets/imgs/feature_icons/features_D.png';

const SectionUseCases = ({ t }) => {
  // 导航动态跳转
  const scrollTo = (element) => {
    scroller.scrollTo(element, {
      duration: 600, // 滚动持续时间（毫秒）
      smooth: 'easeInOutQuart', // 使用贝塞尔曲线进行变速
    });
  };

  const _buildFeatures = ({
    srcImage,
    altString,
    titleString,
    targetElemtName,
  }) => {
    return (
      <div
        className='w-[40vw] md:w-[30vw] lg:w-[20vw] h-[30vh] flex flex-col items-center justify-center bg-white rounded cursor-pointer'
        onClick={() => scrollTo(targetElemtName)}>
        <img
          src={srcImage}
          alt={altString}
          className='w-1/2 lg:w-1/3 h-1/2 object-contain'
        />
        <div className='mt-5 font-bold text-gray-800 text-2xl lg:text-3xl duration-300 text-center tracking-widest-cn'>
          {titleString}
        </div>
      </div>
    );
  };

  return (
    <>
      {/* 背景图 */}
      <div className='absolute bg-slate-100 h-full'>
        <img
          src={features_bg}
          alt='features_bg'
          className='animate-displayFromTransparent z-0 w-full min-h-full object-cover blur-sm'
        />
      </div>
      <div className='pt-6 flex flex-col w-full items-center z-10'>
        <div className='font-bold text-white text-4xl lg:text-6xl duration-300 tracking-widest-cn'>
          {t('应用场景')}
        </div>
        <div className='mt-10 grid grid-cols-2 gap-6'>
          <_buildFeatures
            srcImage={features_A}
            altString='features_A'
            titleString={t('远程诊断')}
            targetElemtName={'feature-a'}
          />
          <_buildFeatures
            srcImage={features_B}
            altString='features_B'
            titleString={t('远程会诊')}
            targetElemtName={'feature-b'}
          />
          <_buildFeatures
            srcImage={features_C}
            altString='features_C'
            titleString={t('远程协助')}
            targetElemtName={'feature-c'}
          />
          <_buildFeatures
            srcImage={features_D}
            altString='features_D'
            titleString={t('远程质控')}
            targetElemtName={'feature-c'}
          />
        </div>
      </div>
    </>
  );
};

SectionUseCases.propTypes = {
  t: PropTypes.func.isRequired,
};

export default SectionUseCases;
