import React, { useEffect, useState } from 'react';
import { useSessionStorage } from 'react-use';
import { useTranslation } from 'react-i18next';
import PropTypes from 'prop-types';
import classNames from 'classnames';

LanguageList.propTypes = {
  isExpend: PropTypes.bool.isRequired,
  urlLanguageParam: PropTypes.string, // 从 url 中获取的语言参数
};

export default function LanguageList({ isExpend, urlLanguageParam }) {
  // 用户配置
  const [languageSessionStorage, setLanguageSessionStorage] = useSessionStorage(
    'language',
    '',
  );
  // 状态
  const [language, setLanguage] = useState(languageSessionStorage);
  const [isDisplay, setIsDisplay] = useState(false);
  const [languageListClassName, setLanguageListClassName] = useState('');

  const { t, i18n } = useTranslation();

  useEffect(() => {
    // 首次加载要隐藏 600ms 等待动画过完
    setTimeout(() => {
      setIsDisplay(true);
    }, 600);
  }, [setIsDisplay]);

  useEffect(() => {
    // 获取浏览器语言
    const browserLanguage =
      navigator.language === 'zh-CN' || navigator.language === 'zh'
        ? 'zh'
        : navigator.language;

    let preferredLanguage = 'en';

    if (i18n.languages.includes(browserLanguage)) {
      preferredLanguage = browserLanguage;
    }
    if (i18n.languages.includes(language)) {
      preferredLanguage = language;
    }
    if (i18n.languages.includes(urlLanguageParam)) {
      preferredLanguage = urlLanguageParam;
    }

    if (preferredLanguage) {
      setLanguage(preferredLanguage);
    }
  }, []);

  useEffect(() => {
    // 语言切换
    i18n.changeLanguage(language);
  }, [language]);

  useEffect(() => {
    setLanguageListClassName(
      classNames('z-20 fixed left-0 right-0 top-0 duration-300', {
        'translate-y-full': isExpend,
        'translate-y-0': !isExpend,
      }),
    );
  }, [isExpend]);

  // 语言切换
  const changeLanguage = (language) => {
    setLanguage(language);
    setLanguageSessionStorage(language);
  };

  // 语言切换下拉菜单 [zh,en]
  const languageTabs = [
    { name: t('CN'), value: 'zh' },
    { name: t('EN'), value: 'en' },
  ];
  if (isDisplay)
    return (
      <div className={languageListClassName}>
        <div className='flex justify-end px-16 md:px-[10%] items-center w-full h-16 bg-blue-900 cursor-default'>
          <div className='group flex h-16'>
            {languageTabs.map((tab) => {
              const tabClassName = classNames(
                'border-white flex items-center h-full mx-3 px-2 font-bold text-white whitespace-nowrap cursor-pointer hover:bg-blue-50 hover:text-blue-800 duration-100',
                {
                  'cursor-default': tab.value === language,
                  'cursor-pointer': tab.value !== language,
                  'border-b-4': tab.value === language,
                  'border-t-4': tab.value === language,
                },
              );
              return (
                <div
                  key={tab.value}
                  className={tabClassName}
                  onClick={() => {
                    changeLanguage(tab.value);
                  }}>
                  <center>{tab.name}</center>
                </div>
              );
            })}
          </div>
        </div>
      </div>
    );
}
