import React, { useEffect, useState } from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';

MobileRouter.propTypes = {
  isExpend: PropTypes.bool.isRequired,
  routers: PropTypes.array.isRequired,
  onClickRouter: PropTypes.func.isRequired,
};

export default function MobileRouter({ isExpend, routers, onClickRouter }) {
  const [isDisplay, setIsDisplay] = useState(false);
  const [MobileRouterClassName, setMobileRouterClassName] = useState('');

  useEffect(() => {
    // 首次加载要隐藏 600ms 等待动画过完
    setTimeout(() => {
      setIsDisplay(true);
    }, 600);
  }, [setIsDisplay]);

  useEffect(() => {
    setMobileRouterClassName(
      classNames('z-20 fixed left-0 right-0 top-0  duration-300', {
        'translate-y-0': isExpend,
        '-translate-y-full': !isExpend,
      }),
    );
  }, [isExpend]);

  if (isDisplay)
    return (
      <div className={MobileRouterClassName}>
        <div className='mt-16 group flex flex-col items-end w-full h-full bg-blue-900 cursor-default'>
          {routers.map((tab) => {
            return (
              <div
                key={tab.value}
                className='border-b border-gray-600 text-right w-full h-full text-xl px-5 py-3 text-white cursor-pointer duration-100'
                onClick={() => {
                  onClickRouter(tab.value);
                }}>
                {tab.name}
              </div>
            );
          })}
        </div>
      </div>
    );
}
